View Source Membrane.AudioFiller (Membrane AudioFiller plugin v0.1.0)
Element ensures that audio will be consistent by filling 'holes' with silence. In order for AudioFiller to work properly, all buffers processed have to have correct timestamps (pts).
element-options
Element options
Passed via struct Membrane.AudioFiller.t/0
min_audio_lossMembrane.Time.t()Default value:
1000000
Minimal time of audio loss in nanoseconds that filler should fill with silence
pads
Pads
input
:input
Accepted formats:
RawAudio| Direction: | :input |
| Availability: | :always |
| Mode: | :pull |
| Demand mode: | :auto |
| Demand unit: | :buffers |
output
:output
Accepted formats:
RawAudio| Direction: | :output |
| Availability: | :always |
| Mode: | :pull |
| Demand mode: | :auto |
Link to this section Summary
Types
Struct containing options for Membrane.AudioFiller
Link to this section Types
Specs
t() :: %Membrane.AudioFiller{min_audio_loss: Membrane.Time.t()}
Struct containing options for Membrane.AudioFiller
Link to this section Functions
Specs
options() :: keyword()
Returns description of options available for this module